Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1120)

Unified Diff: src/snapshot/deserializer.h

Issue 2205973003: [wasm] Serialization/Deserialization of compiled module (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: disable dchecks Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/snapshot/code-serializer.cc ('k') | src/snapshot/deserializer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/snapshot/deserializer.h
diff --git a/src/snapshot/deserializer.h b/src/snapshot/deserializer.h
index 3f66708e56f6c76779c9bf264b3e6c336e40fdfe..9e4bf54b91e7347bc4ee1a0f479d7769f8e3594f 100644
--- a/src/snapshot/deserializer.h
+++ b/src/snapshot/deserializer.h
@@ -30,13 +30,13 @@ class Deserializer : public SerializerDeserializer {
public:
// Create a deserializer from a snapshot byte source.
template <class Data>
- explicit Deserializer(Data* data)
+ explicit Deserializer(Data* data, bool deserializing_user_code = false)
: isolate_(NULL),
source_(data->Payload()),
magic_number_(data->GetMagicNumber()),
external_reference_table_(NULL),
deserialized_large_objects_(0),
- deserializing_user_code_(false),
+ deserializing_user_code_(deserializing_user_code),
next_alignment_(kWordAligned) {
DecodeReservation(data->Reservations());
}
@@ -50,8 +50,8 @@ class Deserializer : public SerializerDeserializer {
MaybeHandle<Object> DeserializePartial(Isolate* isolate,
Handle<JSGlobalProxy> global_proxy);
- // Deserialize a shared function info. Fail gracefully.
- MaybeHandle<SharedFunctionInfo> DeserializeCode(Isolate* isolate);
+ // Deserialize an object graph. Fail gracefully.
+ MaybeHandle<HeapObject> DeserializeObject(Isolate* isolate);
// Add an object to back an attached reference. The order to add objects must
// mirror the order they are added in the serializer.
« no previous file with comments | « src/snapshot/code-serializer.cc ('k') | src/snapshot/deserializer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698